#include "geminc.h"
#include "gemprm.h"
#include "tgcmn.h"

/*
**  Function prototypes.
*/

void tg_icpt( char [][8], char[][8], int * );

char *outstr( char [] );


/************************************************************************
 * tg_icpt                                                              *
 *                                                                      *
 * This routine prints the interface values arrays to the decoder log   *
 * if the verbosity level is 3 or higher.                               *
 *                                                                      *
 * tg_icpt ( rimnem, cimnem, *iret )                                    *
 *                                                                      *
 * Input parameter:                                                     *
 *      rimnem[]        char            Interface mnemonics for reals   *
 *      cimnem[]        char            Interface mnemonics for chars   *
 *                                                                      *
 * Output parameter:                                                    *
 *      *ret            int             Return code                     *
 *                                         0 = normal return            *
 *                                                                      *
 **                                                                     *
 *Log:                                                                  *
 * R. Hollern/NCEP      8/03						*
 ***********************************************************************/

void tg_icpt( char rimnem[][8], char cimnem[][8], int *iret )

{
    int ierwlg;

    unsigned int jj, ntid, nswv, nspw, npcv;

    char logmsg[201];

/*
**  Print out all of the single-level character interface values
**  that are not "missing".
*/
    for ( jj = 0; jj < NCIMN; jj++ ) {
	if ( cintfv.civals[jj][0] != CHSPAC ) {
	    sprintf( logmsg, "%s = ", outstr(cimnem[jj]) );
	    sprintf( &(logmsg[strlen(logmsg)]), "%s\n" ,
		     outstr(cintfv.civals[jj]) );
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
	}
    }

/*
**  Print out all of the single-level real interface values
**  that are not "missing".
*/
    for ( jj = 0; jj < NRSLMN; jj++ ) {
	if ( ! ERMISS( rintfv.rivals[jj] ) ) {
	    sprintf( logmsg, "%s = %10.2f\n",
		     outstr(rimnem[jj]), rintfv.rivals[jj] );
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
	}
    }

/*
**  Print out all of the multi-level interface values.
*/

/*
**  Tide elevation series.
*/
       ntid = ( unsigned int ) rintfv.rivals[(rintfp.irntid)-1];

       sprintf( logmsg, "%s = %u\n",
	     outstr(rimnem[(rintfp.irntid)-1]), ntid );
       dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

       if ( ntid > 0 ) {
         strcpy(   logmsg,      outstr(rimnem[(rintfp.irterc[0])-1]) );
	 strcpy( &(logmsg[8]),  outstr(rimnem[(rintfp.irmrte[0])-1]) );
	 dc_wclg( 3, "DC", 2, logmsg, &ierwlg );

	 for ( jj = 0; jj < ntid; jj++ ) {
	    sprintf( logmsg,
		     "%8.1f %8.1f\n",
		     rintfv.rivals[(rintfp.irterc[jj])-1],
		     rintfv.rivals[(rintfp.irmrte[jj])-1] );
	    dc_wclg( 3, "DC", 2, logmsg, &ierwlg );
         }
      }

/*

**  Set return code.
*/
    *iret = 0;

    return;
}

char *outstr( char string[] ) {

    unsigned short ii;

    static char tmpstr[9];

/*
**  Return a null-terminated copy of string.
*/
    for ( ii = 0; ii < 8; ii++ ) {
	tmpstr[ii] = string[ii];
    }
    tmpstr[8] = '\0';

    return tmpstr;
}
